Welcome to an edX Course! | DemoX.1 Courseware | edX

Skip to main content
Help

## edX Help

For questions on course lectures, homework, tools, or materials for this course, post in the course discussion forum.

Have general questions about edX? You can find lots of helpful information in the edX FAQ.

Have a question about something specific? You can contact the edX general support team directly:

Report a problem Make a suggestion Ask a question

Please note: The edX support team is English speaking. While we will do our best to address your inquiry in any language, our responses will be in English.

Briefly describe your issue* Tell us the details* Include error messages, steps which lead to the issue, etc

## Thank You!

Thank you for your inquiry or feedback. We typically respond to a request within one business day (Monday to Friday, 13:00 UTC to 21:00 UTC.) In the meantime, please review our detailed FAQs where most questions have already been answered.

<div class="xblock xblock-student_view xblock-student_view-vertical" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-usage-id="i4x:;_;_edX;_DemoX.1;_vertical;_f77c35843d944fb286356caff9b41520" data-block-type="vertical" data-course-id="edX/DemoX.1/2014"> <div class="vert-mod"> <div class="vert vert-0" data-id="i4x://edX/DemoX.1/html/8300df2ce3e7434d984417d68a4fa05f"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-runtime-version="1" data-usage-id="i4x:;_;_edX;_DemoX.1;_html;_8300df2ce3e7434d984417d68a4fa05f" data-type="HTMLModule" data-course-id="edX/DemoX.1/2014"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <p><img src="/c4x/edX/DemoX.1/asset/LearningSeriesLogo.png" alt="edX Learning Series" width="820" type="saveimage" target="[object Object]" /></p> </div> </div> <div class="vert vert-1" data-id="i4x://edX/DemoX.1/html/cc5774b6de034b7bb6771dbe221efc44"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-runtime-version="1" data-usage-id="i4x:;_;_edX;_DemoX.1;_html;_cc5774b6de034b7bb6771dbe221efc44" data-type="HTMLModule" data-course-id="edX/DemoX.1/2014"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h2>Let's Take a Tour!</h2> <p>Welcome to the <strong>Courseware</strong>&nbsp;tab! As an edX student, you'll spend a lot of time on this tab. The <strong>Courseware</strong> &nbsp;tab contains most of the course content, but there are also several&nbsp;other useful tabs at the top of the screen. Let's take a look at the video below to find out more.</p> </div> </div> <div class="vert vert-2" data-id="i4x://edX/DemoX.1/video/14459340170c476bb65f73a0a08a076f"> <div class="xblock xblock-student_view xblock-student_view-video xmodule_display xmodule_VideoModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="video" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-runtime-version="1" data-usage-id="i4x:;_;_edX;_DemoX.1;_video;_14459340170c476bb65f73a0a08a076f" data-type="Video" data-course-id="edX/DemoX.1/2014"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "Video"} </script> <h2>Navigating an edX Course</h2> <div id="video_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f" class="video closed" data-streams="1.00:b7xgknqkQk8" data-sub="EDXSPCPJSP13-H010000_100" data-sources='["https://d2f1egay8yehza.cloudfront.net/edx-edx101/EDXSPCPJSP13-H010000_100.mp4", "https://d2f1egay8yehza.cloudfront.net/edx-edx101/EDXSPCPJSP13-H010000_100.webm"]' data-save-state-url="/courses/edX/DemoX.1/2014/xblock/i4x:;_;_edX;_DemoX.1;_video;_14459340170c476bb65f73a0a08a076f/handler/xmodule_handler/save_user_state" data-caption-data-dir="None" data-show-captions="true" data-general-speed="1.0" data-speed="null" data-saved-video-position="0.0" data-start="0.0" data-end="0.0" data-transcript-language="zh" data-transcript-languages='{"zh": "Chinese", "en": "English"}' data-autoplay="False" data-yt-test-timeout="1500" data-yt-api-url="www.youtube.com/iframe_api" data-yt-test-url="gdata.youtube.com/feeds/api/videos/" data-transcript-translation-url="/courses/edX/DemoX.1/2014/xblock/i4x:;_;_edX;_DemoX.1;_video;_14459340170c476bb65f73a0a08a076f/handler/transcript/translation" data-transcript-available-translations-url="/courses/edX/DemoX.1/2014/xblock/i4x:;_;_edX;_DemoX.1;_video;_14459340170c476bb65f73a0a08a076f/handler/transcript/available_translations" data-autohide-html5="False" tabindex="-1" > <div class="focus_grabber first"></div> <div class="tc-wrapper"> <a href="#before-transcript_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f" class="nav-skip sr">Skip to a navigable version of this video's transcript.</a> <article class="video-wrapper"> <span tabindex="0" class="spinner" aria-hidden="false" aria-label="Loading video player"></span> <span tabindex="-1" class="btn-play is-hidden" aria-hidden="true" aria-label="Play video"></span> <div class="video-player-pre"></div> <section class="video-player"> <div id="i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f"></div> <h3 class="hidden">No playable video sources found.</h3> </section> <div class="video-player-post"></div> <section class="video-controls is-hidden"> <div class="slider" title="Video position"></div> <div> <ul class="vcr"> <li><a class="video_control" href="#" title="Play" role="button" aria-disabled="false"></a></li> <li><div class="vidtime">0:00 / 0:00</div></li> </ul> <div class="secondary-controls"> <div class="speeds menu-container"> <a class="speed-button" href="#" title="Speeds" role="button" aria-disabled="false"> <span class="label">Speed</span> <span class="value"></span> </a> <ol class="video-speeds menu" role="menu"></ol> </div> <div class="volume"> <a href="#" role="button" aria-disabled="false" title="Volume" aria-label="Click on this button to mute or unmute this video or press UP or DOWN buttons to increase or decrease volume level."></a> <div role="presentation" class="volume-slider-container"> <div class="volume-slider"></div> </div> </div> <a href="#" class="add-fullscreen" title="Fill browser" role="button" aria-disabled="false">Fill browser</a> <a href="#" class="quality-control is-hidden" title="HD off" role="button" aria-disabled="false">HD off</a> <div class="lang menu-container"> <a href="#" class="hide-subtitles" title="Turn off captions" role="button" aria-disabled="false">Turn off captions</a> </div> </div> </div> </section> <a class="nav-skip sr" id="before-transcript_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f" href="#after-transcript_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f">Skip to end of transcript.</a> </article> <ol id="transcript-captions" class="subtitles" tabindex="0" role="group" aria-label="Activating an item in this group will spool the video to the corresponding time point. To skip transcript, go to previous item."> <li></li> </ol> </div> <a class="nav-skip sr" id="after-transcript_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f" href="#before-transcript_i4x-edX-DemoX_1-video-14459340170c476bb65f73a0a08a076f">Go back to start of transcript.</a> <div class="focus_grabber last"></div> <ul class="wrapper-downloads"> <li class="video-sources video-download-button"> <a href="https://d2f1egay8yehza.cloudfront.net/edx-edx101/EDXSPCPJSP13-H010000_100.mp4">Download video</a> </li> <li class="video-tracks video-download-button"> <a href="/courses/edX/DemoX.1/2014/xblock/i4x:;_;_edX;_DemoX.1;_video;_14459340170c476bb65f73a0a08a076f/handler/transcript/download">Download transcript</a> <div class="a11y-menu-container"> <a class="a11y-menu-button" href="#" title=".srt">.srt</a> <ol class="a11y-menu-list"> <li class="a11y-menu-item active"> <a class="a11y-menu-item-link" href="#srt" title="SubRip (.srt) file" data-value="srt"> SubRip (.srt) file </a> </li> <li class="a11y-menu-item"> <a class="a11y-menu-item-link" href="#txt" title="Text (.txt) file" data-value="txt"> Text (.txt) file </a> </li> </ol> </div> </li> </ul> </div> </div> </div> <div class="vert vert-3" data-id="i4x://edX/DemoX.1/html/14557ffab00340d38b33406712a4c45c"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-runtime-version="1" data-usage-id="i4x:;_;_edX;_DemoX.1;_html;_14557ffab00340d38b33406712a4c45c" data-type="HTMLModule" data-course-id="edX/DemoX.1/2014"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h3><img src="/c4x/edX/DemoX.1/asset/CATemplate_Note__Note.png" alt="Note" type="saveimage" target="[object Object]" width="820" /></h3> <p>Are you taking this course on a mobile device or are you interested in edX's mobile capabilities? If so, hop on over to the <a href="/courses/edX/DemoX.1/2014/jump_to_id/b9a2bcbe15c04836a649c5a037a368cf" target="_blank">Optional: edX Mobile App</a>&nbsp;section.</p> <p></p> </div> </div> <div class="vert vert-4" data-id="i4x://edX/DemoX.1/html/acc7263caba942588c69c987939c9915"> <div class="xblock xblock-student_view xblock-student_view-html xmodule_display xmodule_HtmlModule" data-runtime-class="LmsRuntime" data-init="XBlockToXModuleShim" data-block-type="html" data-request-token="c6ccbca8070f11e597c00ab544b0902d" data-runtime-version="1" data-usage-id="i4x:;_;_edX;_DemoX.1;_html;_acc7263caba942588c69c987939c9915" data-type="HTMLModule" data-course-id="edX/DemoX.1/2014"> <script type="json/xblock-args" class="xblock-json-init-args"> {"xmodule-type": "HTMLModule"} </script> <h2>On to More Content!</h2> <p>Let's continue your student journey by experiencing some example course content. You can select&nbsp;<strong>Week 1</strong>&nbsp;in the course accordion to the left.</p> </div> </div> </div> </div>
© All Rights Reserved

open